==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ast.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documentos",
    "Can't create document" : "Nun pue crease'l documentu",
    "You don't have permission to rename this document" : "Nun tienes permisu pa camudar de nome a esti documentu",
    "Directory saved successfully." : "El direutoriu guardóse correchamente.",
    "An error occurred while changing directory." : "Asocedió un fallu cuando se camudaba'l direutoriu.",
    "Saved" : "Guardáu",
    "Format filter server is down or misconfigured" : "El sirvidor de filtru de formatu cayó o ta mal configuráu",
    "Conversion failed. Check log for details." : "Conversión fallida. Comprueba'l rexistru pa detalles.",
    "document-styles" : "Estilos de documentu",
    "document-content" : "Conteníu del documentu",
    "bold" : "Negrina",
    "italic" : "Cursiva",
    "solid" : "Sólidu",
    "pt" : "pt",
    "Saving..." : "Guardando...",
    "Failed to load documents." : "Fallu al cargar los documentos.",
    "No documents were found. Upload or create a document to get started!" : "Nun s'alcontrarón documentos. ¡Xubi o crea un documentu pa entamar!",
    "No connection to server. Trying to reconnect." : "Nun hai conexón col sirvidor. Intentando reconeutar.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Si dexes esta páxina nel mou d'edición, pue ser que nun se guarden dalgunos datos. Ye preferible usar el botón «Zarrar».",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Nun pudo cargase'l documentu. Comprueba si pues abrilu con un editor de ficheros ODT esternu. Tamién pue ser que yá nun se comparta o se desaniciara de recién.",
    "Save" : "Guardar",
    "Loading documents..." : "Cargando los documentos...",
    "'.' is an invalid file name." : "'.' nun ye un nome de ficheru válidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome inválidu, los caráuteres \"\\\", \"/\", \"<\", \">\", \":\", \"\", \"|\" \"?\" y \"*\" nun tán permitíos.",
    "Align Left" : "Alliniar a la esquierda",
    "Alignment" : "Alliniación",
    "Align Right" : "Alliniar a la derecha",
    "Annotate" : "Anotar",
    "Background" : "Fondu",
    "Bold" : "Negrina",
    "Bottom" : "Inferior",
    "Cancel" : "Encaboxar",
    "Center" : "Centráu",
    "Clone" : "Clonar",
    "Clone this Style" : "Clonar esti estilu",
    "Close" : "Zarrar",
    "Color" : "Color",
    "Create" : "Crear",
    "Decrease Indent" : "Amenorgar sangría",
    "Default Style" : "Estilu por defeutu",
    "Delete" : "Desaniciar",
    "Family" : "Familia",
    "Font" : "Fonte",
    "Font Effects" : "Efeutos de fonte",
    "Format" : "Formatu",
    "Increase Indent" : "Aumentar sangría",
    "Insert Image" : "Inxertar una imaxe",
    "Invite Members" : "Invitar a miembros",
    "Italic" : "Cursiva",
    "Justified" : "Xustificáu",
    "Justify" : "Xustificar",
    "Left" : "Esquierda",
    "Loading" : "Cargando",
    "Members" : "Miembros",
    "New Name:" : "Nome nuevu:",
    "OK" : "Aceutar",
    "Open" : "Abrir",
    "Options" : "Opciones",
    "Paragraph..." : "Párrafu...",
    "Paragraph Styles" : "Estilos de párrafu",
    "Redo" : "Refacer",
    "Right" : "Derechu",
    "Size" : "Tamañu",
    "Spacing" : "Espaciamientu",
    "Strikethrough" : "Tacháu",
    "Style" : "Estilu",
    "Text" : "Testu",
    "Top" : "Superior",
    "Underline" : "Solliñáu",
    "Undo" : "Desfacer",
    "Unknown Author" : "Autor desconocíu",
    "Edit" : "Editar",
    "Share" : "Compartir",
    "guest" : "invitáu",
    "MS Word support (requires openOffice/libreOffice)" : "Sofitu de MS Word (requier openOffice/libreOffice)",
    "Local" : "Llocal",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice ta instaláu nesti sirvidor. El camín pal binariu apúrrese per preview_libreoffice_path en config.php",
    "External" : "Esternu",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice ta instaláu nun sirvidor esternu executando un sirvidor de filtráu de formatu",
    "Disabled" : "Deshabilitáu",
    "No MS Word support" : "Nun esiste sofitu pa MS Word",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL del sirvidor",
    "Apply and test" : "Aplicar y comprobar",
    "New document" : "Documentu nuevu",
    "Upload (max. %s)" : "Xuba (máx. %s)",
    "Upload" : "Xubir",
    "Save new documents to" : "Guardar documentos nuevos en",
    "Wrong password. Please retry." : "Contraseña incorreuta. Inténtalo de nueves.",
    "Password" : "Contraseña",
    "Guest %s" : "Invitáu %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Esti enllaz caducó o enxamás esistió. Pa más detalles, contauta cola persona que lu compartió contigo.",
    "Advanced feature-set" : "Carauterístiques avanzaes",
    "(Unstable)" : "(Inestable)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ast.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documentos",
    "Can't create document" : "Nun pue crease'l documentu",
    "You don't have permission to rename this document" : "Nun tienes permisu pa camudar de nome a esti documentu",
    "Directory saved successfully." : "El direutoriu guardóse correchamente.",
    "An error occurred while changing directory." : "Asocedió un fallu cuando se camudaba'l direutoriu.",
    "Saved" : "Guardáu",
    "Format filter server is down or misconfigured" : "El sirvidor de filtru de formatu cayó o ta mal configuráu",
    "Conversion failed. Check log for details." : "Conversión fallida. Comprueba'l rexistru pa detalles.",
    "Saving..." : "Guardando...",
    "Failed to load documents." : "Fallu al cargar los documentos.",
    "No documents were found. Upload or create a document to get started!" : "Nun s'alcontrarón documentos. ¡Xubi o crea un documentu pa entamar!",
    "No connection to server. Trying to reconnect." : "Nun hai conexón col sirvidor. Intentando reconeutar.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Si dexes esta páxina nel mou d'edición, pue ser que nun se guarden dalgunos datos. Ye preferible usar el botón «Zarrar».",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Nun pudo cargase'l documentu. Comprueba si pues abrilu con un editor de ficheros ODT esternu. Tamién pue ser que yá nun se comparta o se desaniciara de recién.",
    "Save" : "Guardar",
    "Loading documents..." : "Cargando los documentos...",
    "'.' is an invalid file name." : "'.' nun ye un nome de ficheru válidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome inválidu, los caráuteres \"\\\", \"/\", \"<\", \">\", \":\", \"\", \"|\" \"?\" y \"*\" nun tán permitíos.",
    "Align Left" : "Alliniar a la esquierda",
    "Alignment" : "Alliniación",
    "Align Right" : "Alliniar a la derecha",
    "Annotate" : "Anotar",
    "Background" : "Fondu",
    "Bold" : "Negrina",
    "Bottom" : "Inferior",
    "Cancel" : "Encaboxar",
    "Center" : "Centráu",
    "Clone" : "Clonar",
    "Clone this Style" : "Clonar esti estilu",
    "Close" : "Zarrar",
    "Color" : "Color",
    "Create" : "Crear",
    "Decrease Indent" : "Amenorgar sangría",
    "Default Style" : "Estilu por defeutu",
    "Delete" : "Desaniciar",
    "Family" : "Familia",
    "Font" : "Fonte",
    "Font Effects" : "Efeutos de fonte",
    "Format" : "Formatu",
    "Increase Indent" : "Aumentar sangría",
    "Insert Image" : "Inxertar una imaxe",
    "Invite Members" : "Invitar a miembros",
    "Italic" : "Cursiva",
    "Justified" : "Xustificáu",
    "Justify" : "Xustificar",
    "Left" : "Esquierda",
    "Loading" : "Cargando",
    "Members" : "Miembros",
    "New Name:" : "Nome nuevu:",
    "OK" : "Aceutar",
    "Open" : "Abrir",
    "Options" : "Opciones",
    "Paragraph..." : "Párrafu...",
    "Paragraph Styles" : "Estilos de párrafu",
    "Redo" : "Refacer",
    "Right" : "Derechu",
    "Size" : "Tamañu",
    "Spacing" : "Espaciamientu",
    "Strikethrough" : "Tacháu",
    "Style" : "Estilu",
    "Text" : "Testu",
    "Top" : "Superior",
    "Underline" : "Solliñáu",
    "Undo" : "Desfacer",
    "Unknown Author" : "Autor desconocíu",
    "Shared" : "Compartíu",
    "Error" : "Fallu",
    "Error while sharing" : "Fallu mientres la compartición",
    "Error while unsharing" : "Fallu mientres se dexaba de compartir",
    "Error while changing permissions" : "Fallu mientres camudaben los permisos",
    "Shared with you and the group {group} by {owner}" : "Compartíu contigo y col grupu {group} por {owner}",
    "Shared with you by {owner}" : "Compartíu contigo por {owner}",
    "Share" : "Compartir",
    "Share link" : "Compartir enllaz",
    "The public link will expire no later than {days} days after it is created" : "L'enllaz públicu va caducar enantes de {days} díes dende la so creación",
    "Password protect" : "Protexer con contraseña",
    "Password" : "Contraseña",
    "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
    "Email link to person" : "Enllaz de corréu-e a la persona",
    "Send" : "Unviar",
    "Set expiration date" : "Afitar la data de caducidá",
    "Expiration" : "Caducidá",
    "Expiration date" : "Data de caducidá",
    "group" : "grupu",
    "Resharing is not allowed" : "Recompartir nun ta permitíu",
    "Shared in {item} with {user}" : "Compartíu en {item} con {user}",
    "Unshare" : "Dexar de compartir",
    "notify by email" : "notificar per corréu",
    "can share" : "pue compartir",
    "can edit" : "pue editar",
    "access control" : "control d'accesu",
    "create" : "crear",
    "delete" : "desaniciar",
    "Password protected" : "Contraseña protexida",
    "Error unsetting expiration date" : "Fallu desafitando la data de caducidá",
    "Error setting expiration date" : "Fallu afitando la fecha de caducidá",
    "Sending ..." : "Unviando ...",
    "Email sent" : "Corréu-e unviáu",
    "Warning" : "Avisu",
    "Edit" : "Editar",
    "guest" : "invitáu",
    "MS Word support (requires openOffice/libreOffice)" : "Sofitu de MS Word (requier openOffice/libreOffice)",
    "Local" : "Llocal",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice ta instaláu nesti sirvidor. El camín pal binariu apúrrese per preview_libreoffice_path en config.php",
    "External" : "Esternu",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice ta instaláu nun sirvidor esternu executando un sirvidor de filtráu de formatu",
    "Disabled" : "Deshabilitáu",
    "No MS Word support" : "Nun esiste sofitu pa MS Word",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL del sirvidor",
    "Apply and test" : "Aplicar y comprobar",
    "New document" : "Documentu nuevu",
    "Upload (max. %s)" : "Xuba (máx. %s)",
    "Upload" : "Xubir",
    "Save new documents to" : "Guardar documentos nuevos en",
    "Wrong password. Please retry." : "Contraseña incorreuta. Inténtalo de nueves.",
    "Guest %s" : "Invitáu %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Esti enllaz caducó o enxamás esistió. Pa más detalles, contauta cola persona que lu compartió contigo.",
    "Advanced feature-set" : "Carauterístiques avanzaes",
    "(Unstable)" : "(Inestable)"
},
"nplurals=2; plural=(n != 1);");
